Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type HTTPReverseProxy ¶
type HTTPReverseProxy struct {
// contains filtered or unexported fields
}
func (*HTTPReverseProxy) ProxyRequest ¶
func (p *HTTPReverseProxy) ProxyRequest(workerURL url.URL, w http.ResponseWriter, r *http.Request)
type ReverseProxy ¶
type ReverseProxy interface {
// ProxyRequest is a function that proxies the client HTTP request to a
// worker node. It takes the same parameters as a HTTP server handler along
// with the worker node as the first parameter. It is expected to send a
// response to the client using the ResponseWriter object.
ProxyRequest(workerURL url.URL, w http.ResponseWriter, r *http.Request)
}
ReverseProxy is an interface for an object that proxies the client HTTP request to a worker node. The implementation is free to choose any protocol or network stack
func NewHTTPReverseProxy ¶
func NewHTTPReverseProxy() ReverseProxy
Click to show internal directories.
Click to hide internal directories.